@@ -41,12 +41,18 @@ from .document_processor_service import (
     EnableProcessorMetadata,
     EnableProcessorRequest,
     EnableProcessorResponse,
+    EvaluateProcessorVersionMetadata,
+    EvaluateProcessorVersionRequest,
+    EvaluateProcessorVersionResponse,
     FetchProcessorTypesRequest,
     FetchProcessorTypesResponse,
+    GetEvaluationRequest,
     GetProcessorRequest,
     GetProcessorTypeRequest,
     GetProcessorVersionRequest,
     HumanReviewStatus,
+    ListEvaluationsRequest,
+    ListEvaluationsResponse,
     ListProcessorsRequest,
     ListProcessorsResponse,
     ListProcessorTypesRequest,
@@ -61,11 +67,15 @@ from .document_processor_service import (
     SetDefaultProcessorVersionMetadata,
     SetDefaultProcessorVersionRequest,
     SetDefaultProcessorVersionResponse,
+    TrainProcessorVersionMetadata,
+    TrainProcessorVersionRequest,
+    TrainProcessorVersionResponse,
     UndeployProcessorVersionMetadata,
     UndeployProcessorVersionRequest,
     UndeployProcessorVersionResponse,
 )
 from .document_schema import DocumentSchema
+from .evaluation import Evaluation, EvaluationReference
 from .geometry import BoundingPoly, NormalizedVertex, Vertex
 from .operation_metadata import CommonOperationMetadata
 from .processor import Processor, ProcessorVersion
@@ -97,12 +107,18 @@ __all__ = (
     "EnableProcessorMetadata",
     "EnableProcessorRequest",
     "EnableProcessorResponse",
+    "EvaluateProcessorVersionMetadata",
+    "EvaluateProcessorVersionRequest",
+    "EvaluateProcessorVersionResponse",
     "FetchProcessorTypesRequest",
     "FetchProcessorTypesResponse",
+    "GetEvaluationRequest",
     "GetProcessorRequest",
     "GetProcessorTypeRequest",
     "GetProcessorVersionRequest",
     "HumanReviewStatus",
+    "ListEvaluationsRequest",
+    "ListEvaluationsResponse",
     "ListProcessorsRequest",
     "ListProcessorsResponse",
     "ListProcessorTypesRequest",
@@ -117,10 +133,15 @@ __all__ = (
     "SetDefaultProcessorVersionMetadata",
     "SetDefaultProcessorVersionRequest",
     "SetDefaultProcessorVersionResponse",
+    "TrainProcessorVersionMetadata",
+    "TrainProcessorVersionRequest",
+    "TrainProcessorVersionResponse",
     "UndeployProcessorVersionMetadata",
     "UndeployProcessorVersionRequest",
     "UndeployProcessorVersionResponse",
     "DocumentSchema",
+    "Evaluation",
+    "EvaluationReference",
     "BoundingPoly",
     "NormalizedVertex",
     "Vertex",
