@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -65,15 +69,15 @@ class Barcode(proto.Message):
             ``'MEBKM:TITLE:Google;URL:https://www.google.com;;'``.
     """
 
-    format_ = proto.Field(
+    format_: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    value_format = proto.Field(
+    value_format: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    raw_value = proto.Field(
+    raw_value: str = proto.Field(
         proto.STRING,
         number=3,
     )
