@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -1477,20 +1479,30 @@ class Document(proto.Message):
                     Add an element.
                 REMOVE (2):
                     Remove an element identified by ``parent``.
+                UPDATE (7):
+                    Updates any fields within the given
+                    provenance scope of the message. It 'overwrites'
+                    the fields rather than replacing them.  This is
+                    especially relevant when we just want to update
+                    a field value of an entity without also
+                    affecting all the child properties.
                 REPLACE (3):
-                    Replace an element identified by ``parent``.
-                EVAL_REQUESTED (4):
-                    Request human review for the element identified by
+                    Currently unused. Replace an element identified by
                     ``parent``.
+                EVAL_REQUESTED (4):
+                    Deprecated. Request human review for the element identified
+                    by ``parent``.
                 EVAL_APPROVED (5):
-                    Element is reviewed and approved at human
-                    review, confidence will be set to 1.0.
+                    Deprecated. Element is reviewed and approved
+                    at human review, confidence will be set to 1.0.
                 EVAL_SKIPPED (6):
-                    Element is skipped in the validation process.
+                    Deprecated. Element is skipped in the
+                    validation process.
             """
             OPERATION_TYPE_UNSPECIFIED = 0
             ADD = 1
             REMOVE = 2
+            UPDATE = 7
             REPLACE = 3
             EVAL_REQUESTED = 4
             EVAL_APPROVED = 5
@@ -1567,8 +1579,9 @@ class Document(proto.Message):
 
                 This field is a member of `oneof`_ ``source``.
             id (str):
-                Id of the revision.  Unique within the
-                context of the document.
+                Id of the revision, internally generated by
+                doc proto storage. Unique within the context of
+                the document.
             parent (MutableSequence[int]):
                 The revisions that this revision is based on. This can
                 include one or more parent (when documents are merged.) This
@@ -1579,7 +1592,9 @@ class Document(proto.Message):
                 eg. there are ``provenance.parent.revision`` fields that
                 index into this field.
             create_time (google.protobuf.timestamp_pb2.Timestamp):
-                The time that the revision was created.
+                The time that the revision was created,
+                internally generated by doc proto storage at the
+                time of create.
             human_review (google.cloud.documentai_v1.types.Document.Revision.HumanReview):
                 Human Review information of this revision.
         """
