@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
@@ -23,6 +25,7 @@ import proto  # type: ignore
 from google.cloud.documentai_v1.types import document_schema as gcd_document_schema
 from google.cloud.documentai_v1.types import document as gcd_document
 from google.cloud.documentai_v1.types import document_io
+from google.cloud.documentai_v1.types import evaluation as gcd_evaluation
 from google.cloud.documentai_v1.types import operation_metadata
 from google.cloud.documentai_v1.types import processor as gcd_processor
 from google.cloud.documentai_v1.types import processor_type
@@ -42,6 +45,7 @@ __protobuf__ = proto.module(
         "ListProcessorTypesResponse",
         "ListProcessorsRequest",
         "ListProcessorsResponse",
+        "GetProcessorTypeRequest",
         "GetProcessorRequest",
         "GetProcessorVersionRequest",
         "ListProcessorVersionsRequest",
@@ -66,9 +70,18 @@ __protobuf__ = proto.module(
         "SetDefaultProcessorVersionRequest",
         "SetDefaultProcessorVersionResponse",
         "SetDefaultProcessorVersionMetadata",
+        "TrainProcessorVersionRequest",
+        "TrainProcessorVersionResponse",
+        "TrainProcessorVersionMetadata",
         "ReviewDocumentRequest",
         "ReviewDocumentResponse",
         "ReviewDocumentOperationMetadata",
+        "EvaluateProcessorVersionRequest",
+        "EvaluateProcessorVersionMetadata",
+        "EvaluateProcessorVersionResponse",
+        "GetEvaluationRequest",
+        "ListEvaluationsRequest",
+        "ListEvaluationsResponse",
     },
 )
 
@@ -160,7 +173,27 @@ class HumanReviewStatus(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""The final state of human review on a processed document."""
+        r"""The final state of human review on a processed document.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Human review state is unspecified. Most
+                likely due to an internal error.
+            SKIPPED (1):
+                Human review is skipped for the document.
+                This can happen because human review is not
+                enabled on the processor or the processing
+                request has been set to skip this document.
+            VALIDATION_PASSED (2):
+                Human review validation is triggered and
+                passed, so no review is needed.
+            IN_PROGRESS (3):
+                Human review validation is triggered and the
+                document is under review.
+            ERROR (4):
+                Some error happened during triggering human review, see the
+                [state_message] for details.
+        """
         STATE_UNSPECIFIED = 0
         SKIPPED = 1
         VALIDATION_PASSED = 2
@@ -271,7 +304,25 @@ class BatchProcessMetadata(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""Possible states of the batch processing operation."""
+        r"""Possible states of the batch processing operation.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                The default value. This value is used if the
+                state is omitted.
+            WAITING (1):
+                Request operation is waiting for scheduling.
+            RUNNING (2):
+                Request is being processed.
+            SUCCEEDED (3):
+                The batch processing completed successfully.
+            CANCELLING (4):
+                The batch processing was being cancelled.
+            CANCELLED (5):
+                The batch processing was cancelled.
+            FAILED (6):
+                The batch processing has failed.
+        """
         STATE_UNSPECIFIED = 0
         WAITING = 1
         RUNNING = 2
@@ -502,6 +553,20 @@ class ListProcessorsResponse(proto.Message):
     )
 
 
+class GetProcessorTypeRequest(proto.Message):
+    r"""Request message for get processor.
+
+    Attributes:
+        name (str):
+            Required. The processor type resource name.
+    """
+
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
 class GetProcessorRequest(proto.Message):
     r"""Request message for get processor.
 
@@ -879,6 +944,163 @@ class SetDefaultProcessorVersionMetadata(proto.Message):
     )
 
 
+class TrainProcessorVersionRequest(proto.Message):
+    r"""Request message for the create processor version method.
+
+    Attributes:
+        parent (str):
+            Required. The parent (project, location and processor) to
+            create the new version for. Format:
+            ``projects/{project}/locations/{location}/processors/{processor}``.
+        processor_version (google.cloud.documentai_v1.types.ProcessorVersion):
+            Required. The processor version to be
+            created.
+        document_schema (google.cloud.documentai_v1.types.DocumentSchema):
+            Optional. The schema the processor version
+            will be trained with.
+        input_data (google.cloud.documentai_v1.types.TrainProcessorVersionRequest.InputData):
+            Optional. The input data used to train the
+            ``ProcessorVersion``.
+        base_processor_version (str):
+            Optional. The processor version to use as a base for
+            training. This processor version must be a child of
+            ``parent``. Format:
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``.
+    """
+
+    class InputData(proto.Message):
+        r"""The input data used to train a new ``ProcessorVersion``.
+
+        Attributes:
+            training_documents (google.cloud.documentai_v1.types.BatchDocumentsInputConfig):
+                The documents used for training the new
+                version.
+            test_documents (google.cloud.documentai_v1.types.BatchDocumentsInputConfig):
+                The documents used for testing the trained
+                version.
+        """
+
+        training_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message=document_io.BatchDocumentsInputConfig,
+        )
+        test_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            message=document_io.BatchDocumentsInputConfig,
+        )
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    processor_version: gcd_processor.ProcessorVersion = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_processor.ProcessorVersion,
+    )
+    document_schema: gcd_document_schema.DocumentSchema = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=gcd_document_schema.DocumentSchema,
+    )
+    input_data: InputData = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=InputData,
+    )
+    base_processor_version: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+
+
+class TrainProcessorVersionResponse(proto.Message):
+    r"""The response for the TrainProcessorVersion method.
+
+    Attributes:
+        processor_version (str):
+            The resource name of the processor version
+            produced by training.
+    """
+
+    processor_version: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class TrainProcessorVersionMetadata(proto.Message):
+    r"""The metadata that represents a processor version being
+    created.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+        training_dataset_validation (google.cloud.documentai_v1.types.TrainProcessorVersionMetadata.DatasetValidation):
+            The training dataset validation information.
+        test_dataset_validation (google.cloud.documentai_v1.types.TrainProcessorVersionMetadata.DatasetValidation):
+            The test dataset validation information.
+    """
+
+    class DatasetValidation(proto.Message):
+        r"""The dataset validation information.
+        This includes any and all errors with documents and the dataset.
+
+        Attributes:
+            document_error_count (int):
+                The total number of document errors.
+            dataset_error_count (int):
+                The total number of dataset errors.
+            document_errors (MutableSequence[google.rpc.status_pb2.Status]):
+                Error information pertaining to specific
+                documents. A maximum of 10 document errors will
+                be returned. Any document with errors will not
+                be used throughout training.
+            dataset_errors (MutableSequence[google.rpc.status_pb2.Status]):
+                Error information for the dataset as a whole.
+                A maximum of 10 dataset errors will be returned.
+                A single dataset error is terminal for training.
+        """
+
+        document_error_count: int = proto.Field(
+            proto.INT32,
+            number=3,
+        )
+        dataset_error_count: int = proto.Field(
+            proto.INT32,
+            number=4,
+        )
+        document_errors: MutableSequence[status_pb2.Status] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=1,
+            message=status_pb2.Status,
+        )
+        dataset_errors: MutableSequence[status_pb2.Status] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message=status_pb2.Status,
+        )
+
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=operation_metadata.CommonOperationMetadata,
+    )
+    training_dataset_validation: DatasetValidation = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=DatasetValidation,
+    )
+    test_dataset_validation: DatasetValidation = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=DatasetValidation,
+    )
+
+
 class ReviewDocumentRequest(proto.Message):
     r"""Request message for review document method.
 
@@ -903,7 +1125,17 @@ class ReviewDocumentRequest(proto.Message):
     """
 
     class Priority(proto.Enum):
-        r"""The priority level of the human review task."""
+        r"""The priority level of the human review task.
+
+        Values:
+            DEFAULT (0):
+                The default priority level.
+            URGENT (1):
+                The urgent priority level. The labeling
+                manager should allocate labeler resource to the
+                urgent task queue to respect this priority
+                level.
+        """
         DEFAULT = 0
         URGENT = 1
 
@@ -948,7 +1180,18 @@ class ReviewDocumentResponse(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""Possible states of the review operation."""
+        r"""Possible states of the review operation.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                The default value. This value is used if the
+                state is omitted.
+            REJECTED (1):
+                The review operation is rejected by the
+                reviewer.
+            SUCCEEDED (2):
+                The review operation is succeeded.
+        """
         STATE_UNSPECIFIED = 0
         REJECTED = 1
         SUCCEEDED = 2
@@ -991,4 +1234,137 @@ class ReviewDocumentOperationMetadata(proto.Message):
     )
 
 
+class EvaluateProcessorVersionRequest(proto.Message):
+    r"""Evaluates the given ProcessorVersion against the supplied
+    documents.
+
+    Attributes:
+        processor_version (str):
+            Required. The resource name of the
+            [ProcessorVersion][google.cloud.documentai.v1.ProcessorVersion]
+            to evaluate.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``
+        evaluation_documents (google.cloud.documentai_v1.types.BatchDocumentsInputConfig):
+            Optional. The documents used in the
+            evaluation. If unspecified, use the processor's
+            dataset as evaluation input.
+    """
+
+    processor_version: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    evaluation_documents: document_io.BatchDocumentsInputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=document_io.BatchDocumentsInputConfig,
+    )
+
+
+class EvaluateProcessorVersionMetadata(proto.Message):
+    r"""Metadata of the EvaluateProcessorVersion method.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    common_metadata: operation_metadata.CommonOperationMetadata = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=operation_metadata.CommonOperationMetadata,
+    )
+
+
+class EvaluateProcessorVersionResponse(proto.Message):
+    r"""Metadata of the EvaluateProcessorVersion method.
+
+    Attributes:
+        evaluation (str):
+            The resource name of the created evaluation.
+    """
+
+    evaluation: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
+class GetEvaluationRequest(proto.Message):
+    r"""Retrieves a specific Evaluation.
+
+    Attributes:
+        name (str):
+            Required. The resource name of the
+            [Evaluation][google.cloud.documentai.v1.Evaluation] to get.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}/evaluations/{evaluation}``
+    """
+
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class ListEvaluationsRequest(proto.Message):
+    r"""Retrieves a list of evaluations for a given ProcessorVersion.
+
+    Attributes:
+        parent (str):
+            Required. The resource name of the
+            [ProcessorVersion][google.cloud.documentai.v1.ProcessorVersion]
+            to list evaluations for.
+            ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}``
+        page_size (int):
+            The standard list page size.
+            If unspecified, at most 5 evaluations will be
+            returned. The maximum value is 100; values above
+            100 will be coerced to 100.
+        page_token (str):
+            A page token, received from a previous ``ListEvaluations``
+            call. Provide this to retrieve the subsequent page.
+    """
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+
+
+class ListEvaluationsResponse(proto.Message):
+    r"""The response from ListEvaluations.
+
+    Attributes:
+        evaluations (MutableSequence[google.cloud.documentai_v1.types.Evaluation]):
+            The evaluations requested.
+        next_page_token (str):
+            A token, which can be sent as ``page_token`` to retrieve the
+            next page. If this field is omitted, there are no subsequent
+            pages.
+    """
+
+    @property
+    def raw_page(self):
+        return self
+
+    evaluations: MutableSequence[gcd_evaluation.Evaluation] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_evaluation.Evaluation,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
