@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -38,11 +42,11 @@ class Vertex(proto.Message):
             image).
     """
 
-    x = proto.Field(
+    x: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    y = proto.Field(
+    y: int = proto.Field(
         proto.INT32,
         number=2,
     )
@@ -61,11 +65,11 @@ class NormalizedVertex(proto.Message):
             image).
     """
 
-    x = proto.Field(
+    x: float = proto.Field(
         proto.FLOAT,
         number=1,
     )
-    y = proto.Field(
+    y: float = proto.Field(
         proto.FLOAT,
         number=2,
     )
@@ -75,18 +79,18 @@ class BoundingPoly(proto.Message):
     r"""A bounding polygon for the detected image annotation.
 
     Attributes:
-        vertices (Sequence[google.cloud.documentai_v1.types.Vertex]):
+        vertices (MutableSequence[google.cloud.documentai_v1.types.Vertex]):
             The bounding polygon vertices.
-        normalized_vertices (Sequence[google.cloud.documentai_v1.types.NormalizedVertex]):
+        normalized_vertices (MutableSequence[google.cloud.documentai_v1.types.NormalizedVertex]):
             The bounding polygon normalized vertices.
     """
 
-    vertices = proto.RepeatedField(
+    vertices: MutableSequence["Vertex"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Vertex",
     )
-    normalized_vertices = proto.RepeatedField(
+    normalized_vertices: MutableSequence["NormalizedVertex"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="NormalizedVertex",
