@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,14 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import DocumentProcessorServiceTransport
 from .grpc import DocumentProcessorServiceGrpcTransport
 from .grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
-
+from .rest import (
+    DocumentProcessorServiceRestInterceptor,
+    DocumentProcessorServiceRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -29,10 +30,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[DocumentProcessorServiceTransport]]
 _transport_registry["grpc"] = DocumentProcessorServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = DocumentProcessorServiceGrpcAsyncIOTransport
-
+_transport_registry["rest"] = DocumentProcessorServiceRestTransport
 
 __all__ = (
     "DocumentProcessorServiceTransport",
     "DocumentProcessorServiceGrpcTransport",
     "DocumentProcessorServiceGrpcAsyncIOTransport",
+    "DocumentProcessorServiceRestTransport",
+    "DocumentProcessorServiceRestInterceptor",
 )
